@@ -4,13 +4,6 @@
 # Python `imodels` package for interpretable models compatible with scikit-learn.
 # Github repo available [here](https://github.com/csinva/imodels)
 
-# from .tree.iterative_random_forest.iterative_random_forest import IRFClassifier
-# from .tree.optimal_classification_tree import OptimalTreeModel
-from .tree.cart_wrapper import GreedyTreeClassifier, GreedyTreeRegressor
-from .tree.gosdt.pygosdt import OptimalTreeClassifier
-from .tree.c45_tree.c45_tree import C45TreeClassifier
-from .tree.saps import SaplingSumRegressor, SaplingSumClassifier
-from .tree.shrunk_tree import ShrunkTreeRegressor, ShrunkTreeClassifier, ShrunkTreeRegressorCV, ShrunkTreeClassifierCV
 from .algebraic.slim import SLIMRegressor, SLIMClassifier
 from .discretization.discretizer import RFDiscretizer, BasicDiscretizer
 from .discretization.mdlp import MDLPDiscretizer, BRLDiscretizer
@@ -27,13 +20,24 @@ from .rule_set.fpskope import FPSkopeClassifier
 from .rule_set.rule_fit import RuleFitRegressor, RuleFitClassifier
 from .rule_set.skope_rules import SkopeRulesClassifier
 from .rule_set.slipper import SlipperClassifier
+from .tree.c45_tree.c45_tree import C45TreeClassifier
+from .tree.cart_ccp import DecisionTreeCCPClassifier, DecisionTreeCCPRegressor, HSDecisionTreeCCPClassifierCV, \
+    HSDecisionTreeCCPRegressorCV
+# from .tree.iterative_random_forest.iterative_random_forest import IRFClassifier
+# from .tree.optimal_classification_tree import OptimalTreeModel
+from .tree.cart_wrapper import GreedyTreeClassifier, GreedyTreeRegressor
+from .tree.figs import FIGSRegressor, FIGSClassifier
+from .tree.gosdt.pygosdt import OptimalTreeClassifier
+from .tree.gosdt.pygosdt_shrinkage import HSOptimalTreeClassifier, HSOptimalTreeClassifierCV
+from .tree.hierarchical_shrinkage import HSTreeRegressor, HSTreeClassifier, HSTreeRegressorCV, HSTreeClassifierCV
 from .util.distillation import DistilledRegressor
 from .util.explain_errors import explain_classification_errors
+from .util.data_util import get_clean_dataset
 
 CLASSIFIERS = [BayesianRuleListClassifier, GreedyRuleListClassifier, SkopeRulesClassifier,
                BoostedRulesClassifier, SLIMClassifier, SlipperClassifier, BayesianRuleSetClassifier,
                C45TreeClassifier, OptimalTreeClassifier, OptimalRuleListClassifier, OneRClassifier,
                SlipperClassifier,
-               SaplingSumClassifier]  # , IRFClassifier
-REGRESSORS = [RuleFitRegressor, SLIMRegressor, GreedyTreeClassifier, SaplingSumRegressor]
+               FIGSClassifier, HSTreeClassifier, HSTreeClassifierCV]  # , IRFClassifier
+REGRESSORS = [RuleFitRegressor, SLIMRegressor, GreedyTreeClassifier, FIGSRegressor, HSTreeRegressor, HSTreeRegressorCV]
 DISCRETIZERS = [RFDiscretizer, BasicDiscretizer, MDLPDiscretizer, BRLDiscretizer]
