@@ -61,6 +61,8 @@ class BoostedRulesClassifier(RuleSet, BaseEstimator, MetaEstimatorMixin, Classif
         self.classes_ = unique_labels(y)
         np.random.seed(self.random_state)
 
+        if feature_names is None:
+            feature_names = [f'X_{i + 1}' for i in range(X.shape[1])]
         self.feature_dict_ = get_feature_dict(X.shape[1], feature_names)
         self.feature_placeholders = list(self.feature_dict_.keys())
         self.feature_names = list(self.feature_dict_.values())
@@ -70,12 +72,15 @@ class BoostedRulesClassifier(RuleSet, BaseEstimator, MetaEstimatorMixin, Classif
         self.estimators_ = []
         self.estimator_weights_ = []
         self.estimator_errors_ = []
-        self.feature_names = feature_names
+        self.estimator_mean_prediction_ = [] # this is just for printing
+        if feature_names is not None:
+            self.feature_names = feature_names
         for _ in range(self.n_estimators):
             # Fit a classifier with the specific weights
             clf = self.estimator()
             clf.fit(X, y, sample_weight=w)  # uses w as the sampling weight!
             preds = clf.predict(X)
+            self.estimator_mean_prediction_.append(np.mean(preds)) # just for printing
 
             # Indicator function
             miss = preds != y
@@ -121,7 +126,8 @@ class BoostedRulesClassifier(RuleSet, BaseEstimator, MetaEstimatorMixin, Classif
 
         self.rules_without_feature_names_ = rules
         self.rules_ = [
-            replace_feature_name(rule, self.feature_dict_) for rule in self.rules_without_feature_names_
+            replace_feature_name(rule, self.feature_dict_)
+            for rule in self.rules_without_feature_names_
         ]
         self.complexity_ = self._get_complexity()
         return self
@@ -150,9 +156,12 @@ class BoostedRulesClassifier(RuleSet, BaseEstimator, MetaEstimatorMixin, Classif
 
     def __str__(self):
         try:
-            s = 'Mined rules:\n'
-            for est in self.estimators_:
-                s += '\t' + tree_to_code(est, self.feature_names)
+            s = 'BoostedRules:\n'
+            s += 'Rule \u2192 predicted probability (final prediction is weighted sum of all predictions)\n'
+            for i in range(len(self.estimators_)):
+                s += f'  If\033[96m {str(self.rules_[i])}\033[00m \u2192 {self.estimator_mean_prediction_[i]:.2f} (weight: {self.estimator_weights_[i]:.2f})\n'
+            # for est in self.estimators_:
+            #     s += '\t' + tree_to_code(est, self.feature_names)
             return s
         except:
             return f'BoostedRules with {len(self.estimators_)} estimators'
