@@ -40,62 +40,81 @@ def clean_features(X):
     return X.astype(float)
 
 
-def get_clean_dataset(dataset: str = None, data_source: str = 'imodels', data_path='data') -> Tuple[
+def get_clean_dataset(dataset_name: str, data_source: str = 'imodels', data_path='data') -> Tuple[
     np.ndarray, np.ndarray, list]:
-    """Return
+    """Fetch clean data (as numpy arrays) from various sources including imodels, pmlb, openml, and sklearn.
+    If data is not downloaded, will download and cache. Otherwise will load locally
 
     Parameters
     ----------
-    dataset: str
-        csv_file path or dataset id if data_source is specified
+    dataset_name: str
+        dataset_name - unique dataset identifier
     data_source: str
         options: 'imodels', 'pmlb', 'sklearn', 'openml', 'synthetic'
-        boolean - whether dataset is a pmlb dataset name
+    data_path: str
+        path to load/save data (default: 'data')
 
     Returns
     -------
-    X, y, feature_names
+    X: np.ndarray
+        features
+    y: np.ndarray
+        outcome
+    feature_names: list
+
+    Example
+    -------
+    ```
+    # download compas dataset from imodels
+    X, y, feature_names = imodels.get_clean_dataset('compas_two_year_clean', data_source='imodels')
+    # download ionosphere dataset from pmlb
+    X, y, feature_names = imodels.get_clean_dataset('ionosphere', data_source='pmlb')
+    # download liver dataset from openml
+    X, y, feature_names = imodels.get_clean_dataset('8', data_source='openml')
+    # download ca housing from sklearn
+    X, y, feature_names = imodels.get_clean_dataset('california_housing', data_source='sklearn')
+    ```
     """
     assert data_source in ['imodels', 'pmlb', 'sklearn', 'openml', 'synthetic'], data_source + ' not correct'
     if data_source == 'imodels':
-        if not dataset.endswith('csv'):
-            dataset = dataset + '.csv'
-        if not os.path.isfile(dataset):
-            download_imodels_dataset(dataset, data_path)
-        df = pd.read_csv(oj(data_path, 'imodels_data', dataset))
+        if not dataset_name.endswith('csv'):
+            dataset_name = dataset_name + '.csv'
+        if not os.path.isfile(dataset_name):
+            download_imodels_dataset(dataset_name, data_path)
+        df = pd.read_csv(oj(data_path, 'imodels_data', dataset_name))
         X, y = df.iloc[:, :-1].values, df.iloc[:, -1].values
         feature_names = df.columns.values[:-1]
         return np.nan_to_num(X.astype('float32')), y, clean_feat_names(feature_names)
     elif data_source == 'pmlb':
         from pmlb import fetch_data
         feature_names = list(
-            fetch_data(dataset, return_X_y=False, local_cache_dir=oj(data_path, 'pmlb_data')).columns)
+            fetch_data(dataset_name, return_X_y=False, local_cache_dir=oj(data_path, 'pmlb_data')).columns)
         feature_names.remove('target')
-        X, y = fetch_data(dataset, return_X_y=True, local_cache_dir=oj(data_path, 'pmlb_data'))
+        X, y = fetch_data(dataset_name, return_X_y=True, local_cache_dir=oj(data_path, 'pmlb_data'))
         if np.unique(y).size == 2:  # if binary classification, ensure that the classes are 0 and 1
             y -= np.min(y)
         return clean_features(X), y, clean_feat_names(feature_names)
     elif data_source == 'sklearn':
-        if dataset == 'diabetes':
+        if dataset_name == 'diabetes':
             data = sklearn.datasets.load_diabetes()
-        elif dataset == 'california_housing':
+        elif dataset_name == 'california_housing':
             data = sklearn.datasets.fetch_california_housing(data_home=oj(data_path, 'sklearn_data'))
         return data['data'], data['target'], clean_feat_names(data['feature_names'])
     elif data_source == 'openml':  # note this api might change in newer sklearn - should give dataset-id not name
-        data = sklearn.datasets.fetch_openml(data_id=dataset, data_home=oj(data_path, 'openml_data'))
+        data = sklearn.datasets.fetch_openml(data_id=dataset_name, data_home=oj(data_path, 'openml_data'))
         X, y, feature_names = data['data'], data['target'], clean_feat_names(data['feature_names'])
         if isinstance(X, pd.DataFrame):
             X = X.values
         if isinstance(y, pd.Series):
             y = y.values
-        y = define_openml_outcomes(y, dataset)
+        y = define_openml_outcomes(y, dataset_name)
         return clean_features(X), y, clean_feat_names(feature_names)
     elif data_source == 'synthetic':
-        if dataset == 'friedman1':
+        if dataset_name == 'friedman1':
             X, y = sklearn.datasets.make_friedman1(n_samples=200, n_features=10)
-        elif dataset == 'friedman2':
+        elif dataset_name == 'friedman2':
             X, y = sklearn.datasets.make_friedman2(n_samples=200)
-        elif dataset == 'friedman3':
+        elif dataset_name == 'friedman3':
             X, y = sklearn.datasets.make_friedman3(n_samples=200)
         return X, y, ['X_' + str(i + 1) for i in range(X.shape[1])]
 
@@ -122,7 +141,8 @@ def download_imodels_dataset(dataset_fname, data_path: str):
     download_path = f'https://raw.githubusercontent.com/csinva/imodels-data/master/data_cleaned/{dataset_fname}'
     r = requests.get(download_path)
     if r.status_code == 404:
-        raise Exception(f'404 Error for dataset {dataset_fname} (see valid files at https://github.com/csinva/imodels-data/tree/master/data_cleaned)')
+        raise Exception(
+            f'404 Error for dataset {dataset_fname} (see valid files at https://github.com/csinva/imodels-data/tree/master/data_cleaned)')
 
     os.makedirs(oj(data_path, 'imodels_data'), exist_ok=True)
     with open(oj(data_path, 'imodels_data', dataset_fname), 'w') as f:
