@@ -2,50 +2,28 @@ from typing import Iterable, Tuple, List
 
 import numpy as np
 import pandas as pd
-from mlxtend.frequent_patterns import fpgrowth
+from mlxtend import frequent_patterns as mlx
 from sklearn.ensemble import BaggingRegressor, GradientBoostingRegressor, RandomForestRegressor, \
     GradientBoostingClassifier
 from sklearn.tree import DecisionTreeRegressor
 from sklearn.utils.validation import check_array
 
-from imodels.discretization import BRLDiscretizer, SimpleDiscretizer
-from imodels.util.convert import tree_to_rules
+from imodels.util import rule, convert
 
 
-def extract_fpgrowth(X, y,
-                     feature_names,
+def extract_fpgrowth(X,
                      minsupport=0.1,
                      maxcardinality=2,
-                     undiscretized_features=[],
-                     disc_strategy='simple',
-                     disc_kwargs={},
-                     verbose=False) -> Tuple[List[Tuple], BRLDiscretizer]:
-    # deal with pandas data
-    if type(X) in [pd.DataFrame, pd.Series]:
-        if feature_names is None:
-            feature_names = X.columns
-        X = X.values
-    if type(y) in [pd.DataFrame, pd.Series]:
-        y = y.values
-
-    if disc_strategy == 'mdlp':
-        discretizer = BRLDiscretizer(X, y, feature_labels=feature_names, verbose=verbose)
-        discretizer.fit(X, y, undiscretized_features)
-    else:
-        discretizer = SimpleDiscretizer(**disc_kwargs)
-        discretizer.fit(X, feature_names)
-
-    X_df_onehot = discretizer.transform(X)
-
-    # Now find frequent itemsets
-    itemsets_df = fpgrowth(X_df_onehot, min_support=minsupport, max_len=maxcardinality)
+                     verbose=False) -> List[Tuple]:
+    
+    itemsets_df = mlx.fpgrowth(X, min_support=minsupport, max_len=maxcardinality)
     itemsets_indices = [tuple(s[1]) for s in itemsets_df.values]
-    itemsets = [np.array(X_df_onehot.columns)[list(inds)] for inds in itemsets_indices]
+    itemsets = [np.array(X.columns)[list(inds)] for inds in itemsets_indices]
     itemsets = list(map(tuple, itemsets))
     if verbose:
         print(len(itemsets), 'rules mined')
 
-    return itemsets, discretizer
+    return itemsets
 
 
 def extract_rulefit(X, y, feature_names,
@@ -94,13 +72,16 @@ def extract_rulefit(X, y, feature_names,
     else:
         estimators_ = tree_generator.estimators_
 
-    seen_antecedents = set()
+    seen_rules = set()
     extracted_rules = []
-    for estimator in estimators_:
-        for rule_value_pair in tree_to_rules(estimator[0], np.array(feature_names), prediction_values=True):
-            if rule_value_pair[0] not in seen_antecedents:
+    for estimator in estimators_: 
+        for rule_value_pair in convert.tree_to_rules(estimator[0], np.array(feature_names), prediction_values=True):
+
+            rule_obj = rule.Rule(rule_value_pair[0])
+
+            if rule_obj not in seen_rules:
                 extracted_rules.append(rule_value_pair)
-                seen_antecedents.add(rule_value_pair[0])
+                seen_rules.add(rule_obj)
 
     extracted_rules = sorted(extracted_rules, key=lambda x: x[1])
     extracted_rules = list(map(lambda x: x[0], extracted_rules))
@@ -170,6 +151,6 @@ def extract_skope(X, y, feature_names,
 
     extracted_rules = []
     for estimator, features in zip(estimators_, estimators_features_):
-        extracted_rules.append(tree_to_rules(estimator, np.array(feature_names)[features]))
+        extracted_rules.append(convert.tree_to_rules(estimator, np.array(feature_names)[features]))
 
     return extracted_rules, estimators_samples_, estimators_features_
